summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui/views/tabs/browser_tab_strip_controller.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/ui/views/tabs/browser_tab_strip_controller.cc')
-rw-r--r--chrome/browser/ui/views/tabs/browser_tab_strip_controller.cc5
1 files changed, 3 insertions, 2 deletions
diff --git a/chrome/browser/ui/views/tabs/browser_tab_strip_controller.cc b/chrome/browser/ui/views/tabs/browser_tab_strip_controller.cc
index 8cadbb8..6bfd318 100644
--- a/chrome/browser/ui/views/tabs/browser_tab_strip_controller.cc
+++ b/chrome/browser/ui/views/tabs/browser_tab_strip_controller.cc
@@ -396,10 +396,11 @@ void BrowserTabStripController::TabBlockedStateChanged(
}
////////////////////////////////////////////////////////////////////////////////
// BrowserTabStripController, NotificationObserver implementation:
void BrowserTabStripController::Observe(int type,
- const NotificationSource& source, const NotificationDetails& details) {
+ const content::NotificationSource& source,
+ const content::NotificationDetails& details) {
DCHECK(type == chrome::NOTIFICATION_TAB_CLOSEABLE_STATE_CHANGED);
// Note that this notification may be fired during a model mutation and
// possibly before the tabstrip has processed the change.
@@ -396,10 +396,11 @@ void BrowserTabStripController::TabBlockedStateChanged(
}
////////////////////////////////////////////////////////////////////////////////
-// BrowserTabStripController, NotificationObserver implementation:
+// BrowserTabStripController, content::NotificationObserver implementation:
void BrowserTabStripController::Observe(int type,